==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var FragmentBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FragmentBaseDescriptionMetadata, _super);
    function FragmentBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FragmentBaseDescriptionMetadata.b = function (a) {
        if (FragmentBaseDescriptionMetadata.a == null) {
            FragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FragmentBaseDescriptionMetadata.c(FragmentBaseDescriptionMetadata.a);
        }
        if (a.g(FragmentBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(FragmentBaseDescriptionMetadata.a);
    };
    FragmentBaseDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    FragmentBaseDescriptionMetadata.d = function (a) {
        FragmentBaseDescriptionMetadata.b(a);
        a.t("FragmentBase", FragmentBaseDescriptionMetadata.a);
    };
    FragmentBaseDescriptionMetadata.$t = markType(FragmentBaseDescriptionMetadata, 'FragmentBaseDescriptionMetadata');
    FragmentBaseDescriptionMetadata.a = null;
    return FragmentBaseDescriptionMetadata;
}(Base));
export { FragmentBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FragmentBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
var FragmentBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FragmentBaseDescriptionMetadata, _super);
    function FragmentBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FragmentBaseDescriptionMetadata.b = function (a) {
        if (FragmentBaseDescriptionMetadata.a == null) {
            FragmentBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FragmentBaseDescriptionMetadata.c(FragmentBaseDescriptionMetadata.a);
        }
        if (a.j(FragmentBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(FragmentBaseDescriptionMetadata.a);
    };
    FragmentBaseDescriptionMetadata.c = function (a) {
        HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
    };
    FragmentBaseDescriptionMetadata.d = function (a) {
        FragmentBaseDescriptionMetadata.b(a);
        a.z("FragmentBase", FragmentBaseDescriptionMetadata.a);
    };
    FragmentBaseDescriptionMetadata.$t = markType(FragmentBaseDescriptionMetadata, 'FragmentBaseDescriptionMetadata');
    FragmentBaseDescriptionMetadata.a = null;
    return FragmentBaseDescriptionMetadata;
}(Base));
export { FragmentBaseDescriptionMetadata };
